import QtQuick 1.0
import "todoteria.js" as JS

Item {

    function init() {
        inputFieldListName.text = '';
        inputFieldListId.text = '';
        error.visible = false;
    }

    Item {
        id: header
        height: c_rect_size
        width: parent.width

        Text {
            anchors.centerIn: parent
            font.pixelSize: c_font_size*1.5
            font.bold: true
            color: main.inverted ? "white" : "black"
            text: "Add New List"
        }
    }

    Separator {
        id: separator
        anchors.top: header.bottom
    }

    Flickable {
        width: parent.width

        anchors.top: separator.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right

        anchors.topMargin: c_font_size
        anchors.bottomMargin: c_font_size

        contentWidth: parent.width
        contentHeight: form.height + c_font_size

        clip: true

        Column {
            id: form

            anchors.left: parent.left
            anchors.right: parent.right

            anchors.leftMargin: c_font_size
            anchors.rightMargin: c_font_size
            spacing: c_font_size


            Text {
                font.bold: true
                font.pixelSize: c_font_size
                color: main.inverted ? "white" : "black"
                text: "Name:"
            }

            InputField {
                id: inputFieldListName
                width: parent.width
                height: c_rect_size
            }

            Text {
                font.bold: true
                font.pixelSize: c_font_size
                color: main.inverted ? "white" : "black"
                text: "List Id:"
            }

            InputField {
                id: inputFieldListId
                lowerCase: true
                width: parent.width
                height: c_rect_size

                Text {
                    id: waitIndicator
                    visible: false
                    anchors.centerIn: parent
                    color: "grey"
                    text: "Please wait..."
                }
            }

            Button {
                width: parent.width
                text: "Random"
                onButtonClicked: JS.getRandomId()
            }

            Item {
                width: parent.width
                height: c_rect_size

                Button {
                    anchors.left: parent.left
                    text: "OK"
                    onButtonClicked: {
                        if (main.state == "addListWindow") {
                            if (inputFieldListId.text.length > 0) {
                                if (mainWindow.addItem(inputFieldListId.text, inputFieldListName.text)) {
                                    main.state = ""
                                }
                                else {
                                    error.visible = true;

                                }
                            }
                        }
                    }
                }

                Button {
                    text: "Cancel"
                    anchors.right: parent.right
                    onButtonClicked: main.state = ""
                }
            }

            Rectangle {
                id: error
                visible: false;
                height: c_rect_size
                width: parent.width
                color: "#FF8080"

                Text {
                    anchors.centerIn: parent
                    font.bold: true
                    font.pixelSize: c_font_size
                    color: main.inverted ? "white" : "black"
                    wrapMode: Text.WordWrap
                    text: "List with such id is already in use."
                }
            }
        }
    }
}
