import QtQuick 1.0

Item {

    Item {
        id: header
        height: c_rect_size
        width: parent.width

        Text {
            anchors.centerIn: parent
            font.pixelSize: c_font_size*1.5
            font.bold: true
            color: main.inverted ? "white" : "black"
            text: "Help"
        }
    }

    Separator {
        id: separator
        anchors.top: header.bottom
    }

    Flickable {
        anchors.top: separator.bottom
        anchors.bottom: separator2.top
        anchors.left: parent.left
        anchors.right: parent.right

        anchors.topMargin: c_font_size
        anchors.bottomMargin: c_font_size
        anchors.leftMargin: c_font_size
        anchors.rightMargin: c_font_size

        contentHeight: helpText.height
        contentWidth: parent.width - c_rect_size

        clip: true

        Text {
            id: helpText
            width: parent.width
            font.pixelSize: c_font_size
            wrapMode: Text.WordWrap
            textFormat: Text.RichText
            color: main.inverted ? "white" : "black"
            text: "<p>Todoteria is simple todo app and service. The basic idea behind this app is that you use service to create your lists from computer and share with your friends, relatives and/or colleagues.</p>" +
            "<p><b>Main Window</b></p>" +
            "<p>In main windows your lists are displayed. You can add new list by clicking <img src='../images/box_plus" + (main.inverted ? '_inv' : '') +".svg'/> button. After you click this button \"Add New List\" window is opened. In that window you should enter list's name and its Id. List name can be anything you want - it simply must be something meaningful for you (e.g.: Shopping list, Travel check list and etc.). List id identifies your list in Todoteria's web site. If you want unique random Id click \"Random\" button. It will generate 7 symbols unique Id that is not yet used in Todoteria's web site. After you have entered list name and id just click \"OK\" button and your list will be shown in main window.</p>" +
            "<p>At the bottom of window a menu is displayed with following buttons:</p>" +
            "<p><img src='../images/user" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>If you have multiple lists and want to work with them simpler you can create user on todoteria.com site. If you click this button you will be shown login dialog there you can login and use your account from app.</p>" +
            "<p><img src='../images/settings" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>Here you can change various settings. Read section \"Settings window\" below.</p>" +
            "<p><img src='../images/refresh" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>This button works only when you are logged in. It allows synchronizing your list of lists with todoteria.com site.</p>" +
            "<p><img src='../images/help" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>This button shows this help.</p>" +
            "<p><img src='../images/close" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>This button closes application.</p>" +
            "<p><b>Working with lists in main window</b></p>" +
            "<p>You can edit your list by clicking list name (see below \"List Window\"). If you want to delete your list press and hold list for some seconds - delete button will appear. Now you can click delete button and your list will be deleted. You can arrange lists in main window as well: press and hold list's handle (black circle) and after some time you will be able to move list up and down.</p>" +
            "<p><b>List Window</b></p>" +
            "</p>At the top of list window list address is displayed. You can enter this address in your browser on computer and create your list. By clicking <img src='../images/box_plus" + (main.inverted ? '_inv' : '') +".svg'/> button you will be able to add new list item to the list.</p>"+
            "<p>At the bottom of window you can see following buttons:</p>" +
            (is_todoteria_plus ?
            "<p><img src='../images/settings" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>Here you can change various settings. Read section \"Settings window\" below.</p>" : "") +
            "<p><img src='../images/refresh" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>This button allows synchronizing your list between phone and todoteria.com site. Recommended approach is to create list using site from your computer and synchronize with your phone - that's the easiest way to create list on your phone. You can edit your list on your phone as well. If you will synchronize your list after editing your list on your phone your changes will appear in Todoteria's web site as well. This allows sharing your list with other people and edit your list together with them.</p>" +
            "<p><img src='../images/complete" + (main.inverted ? '_inv' : '') +".svg'/></p>" +
            "<p>This button allows checking or unchecking all items in the list.</p>" +
            "<p><b>Working with list in list window</b></p>" +
            "<p>If you want to edit or delete existing list item press and hold it. Popup menu will appear where you can click Edit or Delete options. Clicking \"Delete\" option will delete your list item. You can mark as (not) completed list item by clicking on list row. If you need to change list item's order press and hold list item's handle and after that you can drag and drop your list item.</p>" +
            "<p><b>Settings window</b></p>" +
            (is_todoteria_plus ? "<p><i>Auto synchronize</i> option enables automatic synchronization of list whenever you view/open it.</p>" +
             "<p><i>Show synchronization results</i> - if you are working on lists not alone you might want to see synchronization results. It shows how many items were added, modified and/or removed in your lists.</p>" +
             "<p><i>Unexpiring list</i> - by default todoteria+ creates unexpiring lists. You can change this and set specific expiration's time for lists - note that list expiration's time will be set during synchronization. You can change this at top level and at list level. Notice that setting this at top level affects all individual lists unless different expiration's time is set on the list.</p>" +
             "<p><i>Access list</i> is simply comma-separated list of emails or device Ids that defines who can access that list. All other people or devices will not be able to access this list. There are two helper buttons \"Add IMEI\" that adds your phone's IMEI to access list and \"Add e-mail\" that adds your e-mail to access list. If you are not logged in you will not see \"Add e-mail\" button.</p>"
             : "") +
            "<p>You can change theme by simply selecting appropriate theme button</p>" +
            (is_todoteria_plus ? "<p>As todoteria+ user you can set different theme for each list. Your chosen theme will be saved in the server and will be set in other devices or to other users using the same list."
            : "" ) +
            (!is_todoteria_plus && todoteria_plus_link != '' ?
            "<p><b>Todoteria+</b></p>" +
            "<p>It might happen that free todoteria app version does less than you might want.</p>" +
            "<p>In that case you might want to check-out <a href='"+ todoteria_plus_link +"'>\"Todoteria+\"</a>." +
            "This version will let you create unexpiring lists, private lists (by settings appropriate access rights), set individual theme for each list and more.</p>"
            : "") +
            "<p><b>Web site notes</b></p>" +
            "<p>Please note that lists on Todoteria's web site for regular accounts are kept only for 24 hours from last edit and after that time they will be deleted. Buy todoteria+ or use pro account if you want to have unexpiring list or list with different expiration time. List id is reserved for 100 days and \"Random\" function for other users will not assign Id that is already in use.</p>" +
            "<p><b>Contacts</b></p>" +
            "<p>If you have any questions or suggestions write to help@sandbox.lt.</p>"
            onLinkActivated: {
                Qt.openUrlExternally(link);
            }
        }
    }

    Separator {
        id: separator2
        anchors.bottom: toolbar.top
    }

    Toolbar {
        id: toolbar
        anchors.bottom: parent.bottom
        ToolbarButton {
            image: "back"
            onButtonClicked: {
                main.state = ""
            }
        }
    }
}
