import QtQuick 1.0
import "todoteria.js" as JS

Item {
    function load(id) {
        todoList.list_id = id
        todoList.load();
        if (main.auto_sync)
            todoList.synchronize();
    }

    function addItem(name) {
        todoList.addItem(null, name);
    }

    function editItem(id, name) {
        todoList.editItem(id, name);
    }

    function setModified() {
        todoList.modified = true;
    }

    function setTheme(theme_name) {
        todoList.theme = theme_name;
    }

    Column {
        anchors.fill: parent

        Row {
            height: c_rect_size
            width: parent.width

            Item {
                id: header
                height: c_rect_size
                width: parent.width - copyButton.width - 4
                clip: true

                Text {
                    anchors.centerIn: parent
                    height: c_font_size
                    font.pixelSize: c_font_size
                    color: main.inverted ? "white" : "black"
                    text: "todoteria.com/" + todoList.list_id
                }
            }

            Item {
                height: parent.height
                width: copyButton.width

                Button {
                    id: copyButton
                    anchors.centerIn: parent
                    height: parent.height-4
                    text: 'Copy'

                    anchors.margins: 2

                    onButtonClicked: {
                        clipboard.setText("http://todoteria.com/" + todoList.list_id)
                    }
                }
            }
        }

        Separator {}

        Item {
            width: parent.width
            height: parent.height - header.height - toolbar.height - 4

            TodoList {
                id: todoList
                list_type: 1
                width: parent.width*0.95
                height: parent.height*0.95
                anchors.centerIn: parent

                onListItemClicked: {
                    if (type == 'add') {
                        addItemWindow.init(-1, '')
                        main.state = "addItemWindow"
                    }
                }
            }
        }

        Separator {}

        Toolbar {
            id: toolbar
            ToolbarButton {
                image: 'back'

                onButtonClicked: {
                    JS.setThemeForMainList();
                    main.state = ""
                }
            }

            ToolbarButton {
                visible: is_todoteria_plus
                image: "settings"
                onButtonClicked: {
                    settingsWindow.backState = "listWindow"
                    settingsWindow.list_id = todoList.list_id
                    settingsWindow.initSettings();
                    main.state = "settingsWindow"
                }
            }

            ToolbarButton {
                image: "refresh"
                onButtonClicked: {
                    todoList.synchronize();
                }
            }

            ToolbarButton {
                image: "complete"
                onButtonClicked: {
                    todoList.toggleAll();
                }
            }
        }
    }
}
