import QtQuick 1.0
import "todoteria.js" as JS

Item {

    function init() {
        error.visible = false;
    }

    Item {
        id: header
        height: c_rect_size
        width: parent.width

        Text {
            anchors.centerIn: parent
            font.pixelSize: c_font_size*1.5
            font.bold: true
            color: main.inverted ? "white" : "black"
            text: "User profile"
        }
    }

    Separator {
        id: separator
        anchors.top: header.bottom
    }

    Flickable {
        width: parent.width

        anchors.top: separator.bottom
        anchors.bottom: separator2.top
        anchors.left: parent.left
        anchors.right: parent.right

        anchors.topMargin: c_font_size
        anchors.bottomMargin: c_font_size

        contentWidth: parent.width
        contentHeight: main.email == "" ? loginform.height + c_font_size : logoutform.height + c_font_size

        clip: true

        Column {
            id: loginform

            visible: main.email == ""

            anchors.left: parent.left
            anchors.right: parent.right

            anchors.leftMargin: c_font_size
            anchors.rightMargin: c_font_size
            spacing: c_font_size


            Text {
                font.bold: true
                font.pixelSize: c_font_size
                width: parent.width - c_font_size*2
                wrapMode: Text.WordWrap
                textFormat: Text.RichText
                color: main.inverted ? "white" : "black"
                text: "<a style='color: " + main.link_color +"' href='/'>Do I need todoteria account?</a>"
                onLinkActivated: {
                    main.state = "helpAccountWindow"
                }
            }

            Text {
                font.bold: true
                font.pixelSize: c_font_size
                color: main.inverted ? "white" : "black"
                text: "E-mail:"
            }

            InputField {
                id: inputFieldEmail
                width: parent.width
                height: c_rect_size
            }

            Text {
                font.bold: true
                font.pixelSize: c_font_size
                color: main.inverted ? "white" : "black"
                text: "Password:"
            }

            InputField {
                id: inputFieldPassword
                echoMode: TextInput.Password
                width: parent.width
                height: c_rect_size
            }

            Item {
                height: linkText.height
                width: parent.width

                Text {
                    id: linkText
                    width: parent.width

                    textFormat: Text.RichText
                    wrapMode: Text.WordWrap
                    font.bold: true
                    font.pixelSize: c_font_size
                    color: main.inverted ? "white" : "black"

                    text: 'You can create account in todoteria.com from your computer. Please read <a style="color: ' + main.link_color + '" href="/">Privacy Policy</a> carefully.'
                    onLinkActivated: {
                        main.state = "helpPrivacyWindow"
                    }

                }
            }

            Button {
                width: parent.width
                text: "Login"
                onButtonClicked: {
                    JS.login(inputFieldEmail.text, inputFieldPassword.text);
                }
            }

            Rectangle {
                id: error
                visible: false;
                height: errorText.height
                width: parent.width
                color: "#FF8080"

                Text {
                    id: errorText
                    anchors.centerIn: parent
                    width: parent.width
                    wrapMode: Text.WordWrap
                    font.bold: true
                    font.pixelSize: c_font_size
                    color: main.inverted ? "white" : "black"
                    text: "Wrong email or password."
                }
            }
        }

        Column {
            id: logoutform

            visible: main.email != ""

            anchors.left: parent.left
            anchors.right: parent.right

            anchors.leftMargin: c_font_size
            anchors.rightMargin: c_font_size
            spacing: c_font_size


            Text {
                font.bold: true
                font.pixelSize: c_font_size
                width: parent.width - c_font_size*2
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "You are logged in as " + main.email
            }

            Button {
                width: parent.width
                text: "Logout"
                onButtonClicked: {
                    JS.logoutUser();
                }
            }
        }
    }

    Separator {
        id: separator2
        anchors.bottom: toolbar.top
    }

    Toolbar {
        id: toolbar
        anchors.bottom: parent.bottom
        ToolbarButton {
            image: "back"
            onButtonClicked: {
                main.state = ""
            }
        }
    }
}
