import QtQuick 1.0
import "todoteria.js" as JS

Item {
    function addItem(unique_id, name) {
        return listlist.addItem(unique_id, name);
    }

    function synchronize() {
        listlist.synchronize();
    }

    function setModified() {
        listlist.modified = true;
    }

    function setTheme(theme_name) {
        listlist.theme = theme_name;
    }

    Column {
        anchors.fill: parent

        Item {
            id: header
            height: c_rect_size
            width: parent.width

            Text {
                anchors.centerIn: parent
                font.pixelSize: c_font_size*1.5
                font.bold: true
                color: main.inverted ? "white" : "black"
                text: "Todoteria" + (is_todoteria_plus ? "+" : "")
            }
        }

        Separator {}

        Item {
            id: user
            visible: main.email.length > 0
            height: main.email.length > 0 ? c_rect_size*0.5 : 0
            width: parent.width

            Text {
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width*0.95
                horizontalAlignment: Text.AlignRight
                color: main.inverted ? "white" : "black"

                font.pixelSize: c_font_size*0.75

                text: main.show_email
            }
        }

        Separator {}

        Item {
            width: parent.width
            height: parent.height - header.height - user.height - toolbar.height - 6

            TodoList {
                id: listlist

                list_type: 0

                anchors.centerIn: parent
                width: parent.width*0.95
                height: parent.height*0.95

                onListItemClicked: {
                    if (type == 'item') {
                        listWindow.load(unique_id)
                        main.state = "listWindow"
                    }
                    else if (type == 'add') {
                        addListWindow.init()
                        main.state = "addListWindow"
                    }
                }
            }
        }

        Separator {}

        Toolbar {
            id: toolbar
            width: parent.width
            height: c_rect_size*2

            ToolbarButton {
                image: 'user'
                onButtonClicked: {
                    loginWindow.init()
                    main.state = "loginWindow"
                }
            }

            ToolbarButton {
                image: "settings"
                onButtonClicked: {
                    settingsWindow.backState = ""
                    settingsWindow.list_id = "@"
                    settingsWindow.initSettings();
                    main.state = "settingsWindow"
                }
            }

            ToolbarButton {
                image: main.email == '' ? 'refresh_off' : 'refresh'
                onButtonClicked: {
                    if (main.email != '')
                        listlist.synchronize();
                }
            }

            ToolbarButton {
                image: "help"
                onButtonClicked: {
                    main.state = "helpWindow"
                }
            }

            Item {
                height: c_rect_size*2
                width: main.width - c_rect_size*4/3*(parent.children.length-1)
            }

            ToolbarButton {
                image: "close"
                onButtonClicked: {
                    Qt.quit();
                }
            }
        }
    }

    Component.onCompleted:{
        JS.initUser();
        listlist.list_id = '@'
        listlist.load();
        JS.initAutoSynchronize();
        JS.initShowSynchResults();
        JS.initProTTL();
        if (main.auto_sync)
            listlist.synchronize();
    }
}
