import QtQuick 1.0
import "todoteria.js" as JS
import TodoteriaModule 1.0

Item {
    id: _settingsWindow
    property string backState: "";
    property string list_id: "";
    property int old_ttl;
    property string old_access;

    function initSettings() {
        if (is_todoteria_plus) {
            var ttl = JS.getTTL(list_id);
            _settingsWindow.old_ttl = ttl;
            if (ttl == -1) {
                expirationSettings.unexpiring_list = true;
                expireDays.text = "";
                expireHours.text = "";
                expireMinutes.text = "";
            }
            else {
                expirationSettings.unexpiring_list = false;
                expireDays.text = Math.floor(ttl / (60*60*24));
                expireHours.text = Math.floor(ttl / (60*60)) % 24;
                expireMinutes.text = Math.floor(ttl / (60)) % 60;
            }

            var access = JS.getAccess(list_id);
            accessList.text = access;
            _settingsWindow.old_access = access;
        }
    }

    function setModified() {
        if (list_id == '@')
            mainWindow.setModified();
        else
            listWindow.setModified();
    }

    function setTheme(theme_name) {
        if (list_id == '@')
            mainWindow.setTheme(theme_name);
        else
            listWindow.setTheme(theme_name);
    }

    Item {
        id: header
        height: c_rect_size
        width: parent.width

        Text {
            anchors.centerIn: parent
            font.pixelSize: c_font_size*1.5
            font.bold: true
            color: main.inverted ? "white" : "black"
            text: "Settings"
        }
    }

    Separator {
        id: separator
        anchors.top: header.bottom
    }

    Flickable {
        anchors.top: separator.bottom
        anchors.bottom: separator2.top
        anchors.left: parent.left
        anchors.right: parent.right

        anchors.topMargin: c_font_size
        anchors.bottomMargin: c_font_size
        anchors.leftMargin: c_font_size
        anchors.rightMargin: c_font_size

        contentHeight: helpColumn.height
        contentWidth: parent.width - c_rect_size

        clip: true

        Column {
            id: helpColumn
            spacing: c_font_size

            anchors.left: parent.left
            anchors.right: parent.right

            anchors.leftMargin: 1
            anchors.rightMargin: 1

            Text {
                visible: is_todoteria_plus && list_id == '@'
                width: parent.width
                font.pixelSize: c_font_size
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "Auto synchronize lists on view:"
            }

            Row {
                visible: is_todoteria_plus && list_id == '@'
                width: parent.width
                height: c_rect_size

                Image {
                    height: c_rect_size
                    width: c_rect_size
                    source: "../images/" + (main.auto_sync ? "box_checked" + (main.inverted ? '_inv' : '') + ".svg" : "box_empty" + (main.inverted ? '_inv' : '') + ".svg")
                    smooth: true
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            main.auto_sync = !main.auto_sync;
                            JS.saveAutoSynchronize();
                        }
                    }
                }

                Text {
                    anchors.verticalCenter: parent.verticalCenter
                    font.pixelSize: c_font_size
                    wrapMode: Text.WordWrap
                    color: main.inverted ? "white" : "black"
                    text: "Auto synchronize"
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            main.auto_sync = !main.auto_sync;
                            JS.saveAutoSynchronize();
                        }
                    }
                }
            }

            Text {
                visible: is_todoteria_plus && list_id == '@'
                width: parent.width
                font.pixelSize: c_font_size
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "Show synchronization results if there are changes:"
            }

            Row {
                visible: is_todoteria_plus && list_id == '@'
                width: parent.width
                height: c_rect_size

                Image {
                    height: c_rect_size
                    width: c_rect_size
                    source: "../images/" + (main.show_sync_results ? "box_checked" + (main.inverted ? '_inv' : '') + ".svg" : "box_empty" + (main.inverted ? '_inv' : '') + ".svg")
                    smooth: true
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            main.show_sync_results = !main.show_sync_results;
                            JS.saveShowSynchResults();
                        }
                    }
                }

                Text {
                    anchors.verticalCenter: parent.verticalCenter
                    font.pixelSize: c_font_size
                    wrapMode: Text.WordWrap
                    color: main.inverted ? "white" : "black"
                    text: "Show results"
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            main.show_sync_results = !main.show_sync_results;
                            JS.saveShowSynchResults();
                        }
                    }
                }
            }

            Text {
                visible: is_todoteria_plus
                width: parent.width
                font.pixelSize: c_font_size
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "Set list expiration during synchronization:"
            }

            Column {
                visible: is_todoteria_plus

                id: expirationSettings

                property bool unexpiring_list: true;
                width: parent.width - parent.spacing*2
                spacing: c_font_size

                Row {
                    width: parent.width
                    height: c_rect_size

                    Image {
                        height: c_rect_size
                        width: c_rect_size
                        source: "../images/" + (expirationSettings.unexpiring_list ? "box_checked" + (main.inverted ? '_inv' : '') + ".svg" : "box_empty" + (main.inverted ? '_inv' : '') + ".svg")
                        smooth: true
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                expirationSettings.unexpiring_list = !expirationSettings.unexpiring_list;
                                expirationTimeSettings.visible = !expirationSettings.unexpiring_list;
                            }
                        }

                    }

                    Text {
                        anchors.verticalCenter: parent.verticalCenter
                        font.pixelSize: c_font_size
                        wrapMode: Text.WordWrap
                        color: main.inverted ? "white" : "black"
                        text: "Unexpiring list"
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                expirationSettings.unexpiring_list = !expirationSettings.unexpiring_list;
                            }
                        }
                    }
                }

                Flow {
                    id: expirationTimeSettings

                    visible: !expirationSettings.unexpiring_list
                    width: parent.width
                    spacing: c_rect_size*0.2

                    Row {
                        height: c_rect_size
                        spacing: c_rect_size*0.2
                        InputField {
                            id: expireDays
                            width: c_rect_size*2
                            height: c_rect_size
                        }

                        Text {
                            font.pixelSize: c_font_size
                            anchors.verticalCenter: parent.verticalCenter
                            color: main.inverted ? "white" : "black"
                            text: "d."
                        }
                    }

                    Row {
                        height: c_rect_size
                        spacing: c_rect_size*0.2
                        InputField {
                            id: expireHours
                            width: c_rect_size*2
                            height: c_rect_size
                        }

                        Text {
                            font.pixelSize: c_font_size
                            anchors.verticalCenter: parent.verticalCenter
                            color: main.inverted ? "white" : "black"
                            text: "h"
                        }
                    }

                    Row {
                        height: c_rect_size
                        spacing: c_rect_size*0.2
                        InputField {
                            id: expireMinutes
                            width: c_rect_size*2
                            height: c_rect_size
                        }

                        Text {
                            font.pixelSize: c_font_size
                            anchors.verticalCenter: parent.verticalCenter
                            color: main.inverted ? "white" : "black"
                            text: "min."
                        }
                    }
                }
            }

            Text {
                visible: is_todoteria_plus && !(list_id == '@' && main.email == '')
                width: parent.width
                font.pixelSize: c_font_size
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "Set access during synchronization:"
            }

            Column {
                visible: is_todoteria_plus && !(list_id == '@' && main.email == '')

                width: parent.width
                spacing: c_font_size

                InputField {
                    id: accessList
                    width: parent.width
                    height: c_rect_size
                }

                Flow {
                    width: parent.width
                    spacing: c_font_size

                    Button {
                        text: "Add Device Id"
                        onButtonClicked: {
                            if (accessList.text.indexOf(deviceInfo.imei) == -1)
                                accessList.text += (accessList.text == '' ? '' : ',') + deviceInfo.imei
                        }
                    }

                    Button {
                        visible: main.email != ""
                        text: "Add e-mail"
                        onButtonClicked: {
                            if (accessList.text.indexOf(main.email.toLowerCase()) == -1)
                                accessList.text += (accessList.text == '' ? '' : ',') + main.email.toLowerCase()
                        }
                    }
                }
            }

            Text {
                width: parent.width
                font.pixelSize: c_font_size
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "Choose theme:"
            }

            Grid {
                columns: Math.floor(parent.width / (c_rect_size*2.1))
                spacing: c_rect_size*0.1

                ThemeSelector {
                    name: "rose"
                }

                ThemeSelector {
                    name: "blue"
                }

                ThemeSelector {
                    name: "cyan"
                }

                ThemeSelector {
                    name: "electric"
                }

                ThemeSelector {
                    name: "green"
                }

                ThemeSelector {
                    name: "violet"
                }

                ThemeSelector {
                    name: "yellow"
                }

                ThemeSelector {
                    name: "black"
                }

                ThemeSelector {
                    name: "bubbles"
                    thumb: "bubbles_thumb"
                }

                ThemeSelector {
                    name: "grid"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "purplegrid"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "twisted"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "swirl"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "circlelines"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "winter"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "winter2"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "love"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "chess"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "intruders"
                }

                ThemeSelector {
                    visible: is_todoteria_plus
                    name: "money"
                }
            }

            Text {
                visible: psc.supportsPurchase() && list_id == '@'
                width: parent.width
                font.pixelSize: c_font_size
                font.bold: true
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "Buy pro account for web site:"
            }

            Text {
                visible: psc.supportsPurchase() && list_id == '@'
                width: parent.width
                font.pixelSize: c_font_size
                wrapMode: Text.WordWrap
                color: main.inverted ? "white" : "black"
                text: "With pro account in todoteria.com site you can set access, expiration and theme for individual lists." + (main.email == "" ? " You need account in todoteria.com site and login in app if you want to buy pro account." : "")
            }

            Flow {
                visible: psc.supportsPurchase() && list_id == '@'
                width: parent.width
                spacing: c_font_size

                Text {
                    width: parent.width
                    font.pixelSize: c_font_size
                    wrapMode: Text.WordWrap
                    color: main.inverted ? "white" : "black"
                    text: main.prottl == 0 ? "You don't have pro account." :
                        main.prottl == -1 ? "You have unexpiring pro account." :
                        "Your pro account will expire in less than " + Math.ceil(main.prottl / (24*60*60)) + " days."
                }

                Button {
                    visible: main.email != '' && main.prottl != -1
                    text: "Buy one month pro"
                    onButtonClicked: {
                        JS.net_pingAndPurchase("20081177", "ONEMONTHPRO", "One month pro account for todoteria.com");
                    }
                }

                Button {
                    visible: main.email != '' && main.prottl != -1
                    text: "Buy one year pro"
                    onButtonClicked: {
                        JS.net_pingAndPurchase("20197880", "ONEYEARPRO", "One year pro account for todoteria.com");
                    }
                }

                Text {
                    id: purchaseMessage
                    width: parent.width
                    font.pixelSize: c_font_size
                    color: main.inverted ? "white" : "black"
                    wrapMode: Text.WordWrap
                }
            }
        }
    }

    Separator {
        id: separator2
        anchors.bottom: toolbar.top
    }

    Toolbar {
        id: toolbar
        anchors.bottom: parent.bottom
        ToolbarButton {
            image: "back"
            onButtonClicked: {
                if (is_todoteria_plus) {
                    if (JS.saveTTL(list_id, _settingsWindow.old_ttl));
                        _settingsWindow.setModified();

                    if (JS.saveAccess(list_id, accessList.text, _settingsWindow.old_access))
                        _settingsWindow.setModified();
                }

                main.state = settingsWindow.backState
            }
        }
    }

    PaymentServiceControl {
        id: psc
        onPurchaseResponseSuccess: {
            purchaseMessage.text = "Completing pro account purchase. Please wait..."
            if (SKU == "ONEMONTHPRO")
                JS.net_addpro("1", purchaseId);
            else if (SKU == "ONEYEARPRO")
                JS.net_addpro("2", purchaseId);
        }
        onInfoResponseError: {
            purchaseMessage.text = ""
        }
    }
}
