import QtQuick 1.0
import "todoteria.js" as JS

Item {
    id: todoListBody
    clip: true
    property int list_type: 0;
    property string list_id: "";
    property string theme: "";
    property variant timestamp: 0;
    property bool modified: false;

    signal listItemClicked(int id, string type, string unique_id);

    function load() {
        accessError.visible = false;
        JS.loadFromDB(list_id);
    }

    function addItem(unique_id, name) {
        if (list_type == 0) {
            listlist.insert(listlist.count-1, {'id': '', 'unique_id': unique_id, 'name': name, 'type': 'item'});
        }
        else {
            listlist.insert(listlist.count-1, {'id': '', 'checked': false, 'itemtext': name, 'type': 'item'});
        }
        modified = true;
        JS.updateListInDB(list_id, timestamp, modified);
        return true;
    }

    function editItem(id, name) {
        if (list_type == 1) {
            listlist.setProperty(id, 'itemtext', name);
            modified = true;
            JS.updateListInDB(list_id, timestamp, modified);
        }
    }

    function toggleAll() {
        if (list_type == 1) {
            var new_state = !listlist.get(0)['checked'];

            for (var i = 0; i < listlist.count; i++)
                if (listlist.get(i)['type'] == 'item')
                    listlist.setProperty(i, 'checked', new_state);
            modified = true;
            JS.updateListInDB(list_id, timestamp, modified);
        }
    }

    function synchronize() {
        waitIndicator.visible = true;
        if (modified) {
            JS.net_update();
            modified = false;
        }
        else {
            JS.net_load();
        }
    }

    ListModel {
        id: listlist
    }

    Component {
        id: listItemDelegate

        Row {
            id: listitemrow
            width: parent.width
            height: itemTextText.height+c_font_size > c_font_size*2 ? itemTextText.height+c_font_size : c_font_size*2

            Item {
                id: listHandle
                height: parent.height
                width: c_rect_size

                Image {
                    height: c_rect_size
                    width: parent.width
                    anchors.centerIn: parent
                    source: "../images/" + (type == "item" ? (list_type == 1 && checked ? "box_checked" + (main.inverted ? '_inv' : '') + ".svg" : "box_empty" + (main.inverted ? '_inv' : '') + ".svg") : "box_plus" + (main.inverted ? '_inv' : '') + ".svg")
                    smooth: true
                }

                MouseArea {
                    id: dragArea
                    anchors.fill: listHandle

                    property int positionStarted: 0
                    property int positionEnded: 0
                    property int positionsMoved: positionEnded < positionStarted ? Math.ceil((positionEnded - positionStarted)/parent.height) : Math.floor((positionEnded-positionStarted)/parent.height)
                    property int newPosition: index + positionsMoved
                    property bool held: false
                    drag.axis: Drag.YAxis
                    onClicked: {
                        if (type == 'add') {
                            if (list_type == 0)
                                listItemClicked(id, type, unique_id);
                            else if (list_type == 1)
                                listItemClicked(id, type, itemtext);
                        }
                        else if (type == 'item') {
                            if (list_type == 0) {
                                listItemClicked(id, type, unique_id);
                            }
                            else if (list_type == 1) {
                                listlist.setProperty(index, "checked", !checked)
                                modified = true;
                                JS.updateListInDB(list_id, timestamp, modified);
                            }
                        }
                    }
                    onPressAndHold: {
                        if (type == 'item') {
                            listitemrow.z = 2
                            positionStarted = listitemrow.y
                            dragArea.drag.target = listitemrow
                            listitemrow.opacity = 0.5
                            listview.interactive = false
                            held = true
                            drag.maximumY = (todoListBody.height - parent.height - 1 + listview.contentY)
                            drag.minimumY = listview.contentY
                        }
                    }

                    onPositionChanged: {
                        positionEnded = listitemrow.y
                    }

                    onReleased: {
                        if (held == true) {
                            if (newPosition < 1) {
                                if (index != 0) {
                                    listlist.move(index,0,1)
                                    modified = true;
                                    JS.updateListInDB(list_id, timestamp, modified);
                                }
                                else {
                                    listitemrow.y = positionStarted
                                }
                            } else if (newPosition > listview.count - 2) {
                                if (index != listview.count - 2) {
                                    listlist.move(index,listview.count - 2,1)
                                    modified = true;
                                    JS.updateListInDB(list_id, timestamp, modified);
                                }
                                else {
                                    listitemrow.y = positionStarted
                                }
                            }
                            else {
                                if (index != newPosition) {
                                    listlist.move(index,newPosition,1)
                                    modified = true;
                                    JS.updateListInDB(list_id, timestamp, modified);
                                }
                                else {
                                    listitemrow.y = positionStarted
                                }
                            }

                            listitemrow.opacity = 1
                            listitemrow.z = 1
                            listview.interactive = true
                            dragArea.drag.target = null
                            held = false
                        }
                    }
                }
            }

            Column {
                width: parent.width - listHandle.width
                height: parent.height

                Row {
                    width: parent.width - anchors.leftMargin
                    height: parent.height - 2

                    Text {
                        id: itemTextText
                        width: parent.width
                        anchors.verticalCenter: parent.verticalCenter
                        text: list_type == 0 ? name + (unique_id != '' ? ' (' + unique_id + ')' : '') : itemtext
                        font.pixelSize: c_font_size
                        wrapMode: Text.WordWrap

                        color: (listRowMA.pressed || dragArea.pressed) ? "#033f91" : (main.inverted ? "white" : "black")

                        MouseArea {
                            id: listRowMA
                            anchors.fill: parent
                            onClicked: {
                                if (list_type == 0)
                                    listItemClicked(id, type, unique_id);
                                else if (list_type == 1) {
                                    if (type == 'add') {
                                        listItemClicked(id, type, itemtext);
                                    }
                                    else {
                                        listlist.setProperty(index, "checked", !checked)
                                        modified = true;
                                        JS.updateListInDB(list_id, timestamp, modified);
                                    }
                                }
                            }
                            onPressAndHold: {
                                if (type == 'item') {
                                    actionMenu.setCenter(mouseX, -listview.contentY+listitemrow.y+mouseY)
                                    if (list_type == 0)
                                        actionMenu.show(list_type, index, unique_id);
                                    else
                                        actionMenu.show(list_type, index, itemtext);
                                }
                            }
                        }
                    }
                }

                Item {
                    width: parent.width
                    height: 2
                    Rectangle {
                        anchors.centerIn: parent
                        width: parent.width
                        height: 2
                        color: "#c0c0c0"
                    }
                }
            }
        }
    }

    ListView {
        id: listview
        anchors.fill: parent

        model: listlist
        delegate: listItemDelegate
    }

    Rectangle {
        id: waitIndicator
        anchors.fill: parent
        visible: false
        color: "white"
        opacity: 0.8

        Image {
            anchors.centerIn: parent
            source: "../images/wait" + (main.inverted ? '_inv' : '') + ".svg"
            height: parent.height / 4
            width: height
            smooth: true
        }
    }

    Rectangle {
        id: accessError
        anchors.fill: parent
        visible: false
        color: "white"
        opacity: 0.8
        Text {
            anchors.centerIn: parent
            wrapMode: Text.WordWrap
            width: parent.width*0.8
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: c_font_size
            color: "red"
            text: "You don't have access rights to this list."
        }
    }

    ActionMenu {
        id: actionMenu
    }

    ResultsWindow {
        id: resultsWindow
    }
}
