var g_database = null;

function getDatabase() {
    if (g_database != null)
        return g_database;

    g_database = openDatabaseSync("TODOTERIADB", "", "Todoteria database", 2000000);

    if (g_database.version == "") {
        g_database.changeVersion("", "1.0",
            function(tx) {
                tx.executeSql('CREATE TABLE IF NOT EXISTS lists(id integer primary key not null, name TEXT NOT NULL, uniqueid TEXT NOT NULL, timestamp INTEGER NOT NULL, modified BOOLEAN NOT NULL, orderid integer, list TEXT NOT NULL)');
                tx.executeSql("CREATE UNIQUE INDEX IF NOT EXISTS lists_idx_1 ON lists(uniqueid)");

                console.log('Database created');
            });
    }

    if (g_database.version == "1.0") {
        g_database.changeVersion("1.0", "1.1",
            function(tx) {
                var res = tx.executeSql("SELECT id, uniqueid, name FROM lists ORDER BY orderId");
                var list = [];
                for (var idx = 0; idx < res.rows.length; idx++) {
                    var item = {'id': res.rows.item(idx).id,
                        'text': '+' + res.rows.item(idx).uniqueid + '|'
                                + res.rows.item(idx).name};

                    list.push(item);
                }

                var meta_list = JSON.stringify(list);
                var res = tx.executeSql("INSERT INTO lists(name, uniqueid, timestamp, modified, list, orderid) VALUES(?, ?, 0, 1, ?, ?)",
                        ['', '@', meta_list, 0]);

                tx.executeSql('CREATE TABLE IF NOT EXISTS user(email TEXT NOT NULL, login_token TEXT NOT NULL)');
                console.log('Database updated to 1.1');
            });
    }

    if (g_database.version == "1.1") {
        g_database.changeVersion("1.1", "1.2",
            function(tx) {
                tx.executeSql('CREATE TABLE IF NOT EXISTS settings(theme TEXT NOT NULL)');
                console.log('Database updated to 1.2');
            });
    }

    if (g_database.version == "1.2") {
        g_database.changeVersion("1.2", "1.3",
            function(tx) {
                tx.executeSql('ALTER TABLE lists ADD COLUMN theme TEXT')
                tx.executeSql('ALTER TABLE lists ADD COLUMN ttl TEXT')
                tx.executeSql('ALTER TABLE lists ADD COLUMN access TEXT')
                tx.executeSql('UPDATE lists SET theme = (SELECT theme FROM settings) WHERE uniqueid = "@"')
                tx.executeSql('DROP TABLE settings')
                tx.executeSql('CREATE TABLE IF NOT EXISTS settings(autosync BOOLEAN NOT NULL DEFAULT 0 , showsyncresults BOOLEAN NOT NULL DEFAULT 0 )');
                console.log('Database updated to 1.3');
            });
    }

    if (g_database.version == "1.3") {
        g_database.changeVersion("1.3", "1.4",
            function(tx) {
                tx.executeSql('ALTER TABLE settings ADD COLUMN prottl INTEGER NOT NULL DEFAULT 0')
                console.log('Database updated to 1.4');
            });
    }

    return g_database;
}

/* Task handling */
function getJSONList() {
    var list = [];
    for (var i = 0; i < listlist.count; i++) {
        var li = listlist.get(i);

        if (li['type'] == 'item') {
            var item;

            if (list_type == 0) {
                item = {'text': '+' + li['unique_id'] + '|' + li['name']};
            }
            else { // list_type == 1
                item = {'text': (li['checked'] ? '+' : '-') + li['itemtext']};

            }

            if (li['id'] !== undefined && li['id'].length > 0)
                item['id'] = li['id'];

            list.push(item);
        }
    }

    return JSON.stringify(list);
}

function loadList(list_data) {
    listlist.clear();
    for (var i = 0; i < list_data.length; i++) {
        var li = list_data[i];
        var itemtext = li['text'];

        if (list_type == 0) {
            var data = itemtext.substr(1).split('|', 2);
            listlist.append({'id': li['id'], 'unique_id': data[0], 'name': data[1], 'type': 'item'});
        }
        else if (list_type == 1) {
            var checked = itemtext[0] == '+';
            itemtext = itemtext.substr(1);

            listlist.append({'id': li['id'], 'checked': checked, 'itemtext': itemtext, 'type': 'item'});
        }
    }

    if (list_type == 0)
        listlist.append({'id': '', 'name': 'Add new list', 'unique_id': '', 'type': 'add'});
    else
        listlist.append({'id': '', 'itemtext': 'Add new item', 'checked': false, 'type': 'add'});
}

function setTheme(theme) {
    if (theme != null && theme != '') {
        themeImage.source = "../images/background_" + theme + ".png"
        if (theme == 'black')
            main.inverted = true;
        else
            main.inverted = false;

        setLinkColor(theme);
    }
}

function setThemeForMainList() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT theme FROM lists WHERE uniqueid = '@'");
            if (res.rows.length > 0) {
                setTheme(res.rows.item(0).theme);
            }
        }
    )
}

function loadFromDB(list_id) {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT list, timestamp, modified, theme FROM lists WHERE uniqueid = ?", [list_id,]);
            if (res.rows.length == 1) {
                timestamp = res.rows.item(0).timestamp;
                modified = res.rows.item(0).modified;
                var list_data = JSON.parse(res.rows.item(0).list);
                loadList(list_data);
                setTheme(res.rows.item(0).theme);
            }
            else {
                timestamp = 0;
                modified = false;
                loadList([]);
            }

            todoListBody.theme = "";
        }
    )
}

function updateListInDB(uniqueId, timestamp, modified) {
    var db = getDatabase();
    var list_str = getJSONList();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT id FROM lists WHERE uniqueid = ?", [list_id]);
            if (res.rows.length == 0)
                tx.executeSql("INSERT INTO lists(list, timestamp, modified, uniqueid, name) VALUES(?, ?, ?, ?, '')", [list_str, timestamp, modified, uniqueId]);
            else
                tx.executeSql("UPDATE lists SET list = ?, timestamp = ?, modified = ? WHERE uniqueid = ?", [list_str, timestamp, modified, uniqueId]);
        }
    )
};

function removeListFromDB(uniqueId) {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            tx.executeSql("DELETE FROM lists WHERE uniqueId = ?", [uniqueId]);
        }
    )
};

function setShowEmail() {
    if (main.email.length > 30) {
        main.show_email = main.email.substr(0, main.email.indexOf('@'));
    }
    else
        main.show_email = main.email;
}

function initUser() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT email, login_token FROM user");

            if (res.rows.length > 0) {
                main.email = res.rows.item(0).email;

                setShowEmail();

                main.login_token = res.rows.item(0).login_token;
            }

            setThemeForMainList();
        }
    )
}

/* User DB Handling */
function addUserToDB(email, login_token) {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            tx.executeSql("DELETE FROM user");
            tx.executeSql("INSERT INTO user(email, login_token) VALUES(?, ?)",
                        [email, login_token]);
        }
    )
};

function logoutUser() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            tx.executeSql("DELETE FROM user");
        }
    )

    main.email = "";
    main.show_email = "";
    main.login_token = "";
    main.state = "loginWindow";
}

/* Theme */

function saveTheme(list_id, theme_name) {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT id FROM lists WHERE uniqueid = ?", [list_id]);
            if (res.rows.length == 0)
                tx.executeSql("INSERT INTO lists(list, timestamp, modified, uniqueid, name, theme) VALUES('[]', 0, 0, ?, '', ?)", [list_id, theme_name]);
            else
                tx.executeSql("UPDATE lists SET theme = ? WHERE uniqueid = ?", [theme_name, list_id]);
        }
    )
}

/* TTL */

function getTTL(list_id) {
    var db = getDatabase();
    var ttl;

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT ttl FROM lists WHERE uniqueid = ?", [list_id]);
            if (res.rows.length == 0 || res.rows.item(0).ttl == '')
                res = tx.executeSql("SELECT ttl FROM lists WHERE uniqueid = '@'");

            ttl = res.rows.item(0).ttl;

            if (ttl == '')
                ttl = -1;
        }
    )

    return ttl;
}


function saveTTL(list_id, old_ttl) {
    var ttl = -1;
    if (!expirationSettings.unexpiring_list) {
        var days = parseInt(expireDays.text);
        days = isNaN(days) ? 0 : days;
        var hours = parseInt(expireHours.text);
        hours = isNaN(hours) ? 0 : hours;
        var min = parseInt(expireMinutes.text);
        min = isNaN(min) ? 0 : min;

        ttl =  days * 60 * 60 * 24 + hours * 60 * 60 + min * 60;
    }

    if (old_ttl == ttl)
        return false;

    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT id FROM lists WHERE uniqueid = ?", [list_id]);
            if (res.rows.length == 0)
                tx.executeSql("INSERT INTO lists(list, timestamp, modified, uniqueid, name, ttl) VALUES('[]', 0, 1, ?, '', ?)", [list_id, ttl]);
            else
                tx.executeSql("UPDATE lists SET ttl = ?, modified = 1 WHERE uniqueid = ?", [ttl, list_id]);
        }
    )
    return true;
}

/* Access */

function getAccess(list_id) {
    var db = getDatabase();
    var access = '';

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT access FROM lists WHERE uniqueid = ?", [list_id]);
            if (res.rows.length > 0)
                access = res.rows.item(0).access;
        }
    )

    return access;
}


function saveAccess(list_id, access, old_access) {
    if (access == old_access)
        return false;

    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT id FROM lists WHERE uniqueid = ?", [list_id]);
            if (res.rows.length == 0)
                tx.executeSql("INSERT INTO lists(list, timestamp, modified, uniqueid, name, access) VALUES('[]', 0, 1, ?, '', ?)", [list_id, access]);
            else
                tx.executeSql("UPDATE lists SET access = ?, modified = 1 WHERE uniqueid = ?", [access, list_id]);
        }
    )
    return true;
}

/* Pro TTL */

function initProTTL() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT prottl FROM settings");
            if (res.rows.length > 0)
                main.prottl = res.rows.item(0).prottl
        }
    )
}

function saveProTTL(prottl) {
    main.prottl = prottl;

    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT prottl FROM settings");
            if (res.rows.length == 0)
                tx.executeSql("INSERT INTO settings(prottl) VALUES(?)", [prottl]);
            else
                tx.executeSql("UPDATE settings SET prottl = ?", [prottl]);
        }
    )
    return true;
}

/* Auto synchronize */

function initAutoSynchronize() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT autosync FROM settings");
            if (res.rows.length > 0)
                main.auto_sync = res.rows.item(0).autosync == 1
        }
    )
}


function saveAutoSynchronize() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT autosync FROM settings");
            if (res.rows.length == 0)
                tx.executeSql("INSERT INTO settings(autosync) VALUES(?)", [main.auto_sync ? 1 : 0]);
            else
                tx.executeSql("UPDATE settings SET autosync = ?", [main.auto_sync ? 1 : 0]);
        }
    )
}

/* Show synch results */

function initShowSynchResults() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT showsyncresults FROM settings");
            if (res.rows.length > 0)
                main.show_sync_results = res.rows.item(0).showsyncresults == 1
        }
    )
}


function saveShowSynchResults() {
    var db = getDatabase();

    db.transaction(
        function(tx) {
            var res = tx.executeSql("SELECT showsyncresults FROM settings");
            if (res.rows.length == 0)
                tx.executeSql("INSERT INTO settings(showsyncresults) VALUES(?)", [main.show_sync_results ? 1 : 0]);
            else
                tx.executeSql("UPDATE settings SET showsyncresults = ?", [main.show_sync_results ? 1 : 0]);
        }
    )
}

function showSyncResultsIfNecessary(added, modified, removed) {
    if (main.showsyncresults && !(added == 0 && modified == 0 && removed == 0)) {
        resultsWindow.added = added;
        resultsWindow.modified = modified;
        resultsWindow.removed = removed;
        resultsWindow.visible = true;
    }
}

function checkListResults(new_list_data) {
    var list_map = {}

    for (var i = 0; i < listlist.count; i++) {
        var li = listlist.get(i);

        if (li['type'] == 'item') {
            var text;

            if (list_type == 0) {
                text = '+' + li['unique_id'] + '|' + li['name'];
            }
            else { // list_type == 1
                text = (li['checked'] ? '+' : '-') + li['itemtext'];

            }

            if (li['id'] !== undefined && li['id'].length > 0)
                list_map[li['id']] = text;
        }
    }

    var added = 0, modified = 0;
    for (var i = 0; i < new_list_data.length; i++) {
        var li = new_list_data[i];
        var itemtext = li['text'];

        if (li['id'] in list_map) {
            if (itemtext != list_map[li['id']])
                modified += 1
            delete list_map[li['id']];
        }
        else {
            added += 1;
        }
    }

    var removed = Object.keys(list_map).length;
    showSyncResultsIfNecessary(added, modified, removed);
}


/* Network commands */

function getRandomId() {
    waitIndicator.visible = true;
    var xhr = new XMLHttpRequest();
    xhr.open("POST", "http://todoteria.com", true);
    xhr.setRequestHeader('Accept', 'application/json');
    xhr.onreadystatechange = function() {
        if (xhr.readyState == xhr.DONE) {
            if (xhr.status == 200) {
                var data = JSON.parse(xhr.responseText);
                if (inputFieldListName.text.length == 0 ||
                        inputFieldListName.text == inputFieldListId.text)
                    inputFieldListName.text = data["name"]
                inputFieldListId.text = data["name"]
            }
            waitIndicator.visible = false;
        }
    }

    xhr.send();
}

function net_load() {
    if (list_type == 0 && main.email == '')
        return;

    var xhr = new XMLHttpRequest();

    var url = "http://todoteria.com/" + encodeURIComponent(list_type == 0 ? main.email : list_id) + '?'
            + (timestamp > 0 ? 'timestamp=' + timestamp : '')
            + (main.email != "" ? '&email=' + encodeURIComponent(main.email) : '')
            + (main.login_token != "" ? '&logintoken=' + encodeURIComponent(main.login_token) : '');

    if (is_todoteria_plus) {
        var email = main.email;
        if (email == '') {
            email = deviceInfo.imei;
            url += '&email=' + email;
        }

        var rn = Math.floor((Math.random()*100)+1);
        var secret = plushelper.getSecret(email, rn);
        url += '&secret=' + secret + '&rn=' + rn;
    }

    xhr.open("GET", url, true);
    xhr.setRequestHeader('Accept', 'application/json');
    xhr.onreadystatechange = function() {
        if (xhr.readyState == xhr.DONE) {
            if (xhr.status == 200) {
                var data = JSON.parse(xhr.responseText);

                timestamp = data['timestamp'];

                var list_data = JSON.parse(data['list']);

                checkListResults(list_data);
                loadList(list_data);

                updateListInDB(list_id, timestamp, false);
                saveTheme(list_id, data['theme']);
                setTheme(data['theme']);
                saveAccess(list_id, data['access']);
                saveProTTL(data['prottl']);

                accessError.visible = false;
                waitIndicator.visible = false;
            }
            else if (xhr.status == 403) {
                accessError.visible = true;
                waitIndicator.visible = false;
            }
            else if (xhr.status == 401) {
                logoutUser();
                waitIndicator.visible = false;
            }
            else if (xhr.status == 404) {
                net_update();
            }
            else {
                waitIndicator.visible = false;
            }
        }
    }

    xhr.send();
}


function net_update() {
    if (list_type == 0 && main.email == '')
        return;

    var list_str = getJSONList();

    var urlParameters = "list=" + encodeURIComponent(list_str)
        + "&timestamp=" + timestamp
        + (main.email != "" ? '&email=' + encodeURIComponent(main.email) : '')
        + (main.login_token != "" ? '&logintoken=' + encodeURIComponent(main.login_token) : '');

    if (is_todoteria_plus) {
        var email = main.email;
        if (email == '') {
            email = deviceInfo.imei;
            urlParameters += '&email=' + encodeURIComponent(email);
        }

        if (theme != "")
            urlParameters += '&theme=' + theme;

        if (list_type != 0) {
            var ttl = getTTL(list_id);
            if (ttl != -1)
                urlParameters += '&ttl=' + ttl;
        }

        if (list_str != '[]') {
            var access = getAccess(list_id);
            urlParameters += '&access=' + encodeURIComponent(access);
        }

        var secret = plushelper.getSecret(list_str, email);
        urlParameters += '&secret=' + encodeURIComponent(secret);
    }

    var xhr = new XMLHttpRequest();
    xhr.open("PUT", "http://todoteria.com/" + (list_type == 0 ? main.email : list_id), true);
    xhr.setRequestHeader('Accept', 'application/json');
    xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
    xhr.setRequestHeader("Content-Length", urlParameters.length);

    xhr.onreadystatechange = function() {
        if (xhr.readyState == xhr.DONE) {
            if (xhr.status == 200) {
                var data = JSON.parse(xhr.responseText);

                timestamp = data['timestamp'];

                var list_data = JSON.parse(data['list']);
                loadList(list_data);

                updateListInDB(list_id, timestamp, false);
                saveTheme(list_id, data['theme']);
                setTheme(data['theme']);

                saveAccess(list_id, data['access']);
                saveProTTL(data['prottl']);

                showSyncResultsIfNecessary(data['added'], data['modified'], data['removed']);

                accessError.visible = false;
            }
            else if (xhr.status == 403) {
                accessError.visible = true;
            }
            else if (xhr.status == 401) {
                logoutUser();
            }
            waitIndicator.visible = false;
        }
    }

    xhr.send(urlParameters);
}

function login(email, password) {
    var urlParameters = "email=" + encodeURIComponent(email) +
        "&password=" + encodeURIComponent(password);

    var xhr = new XMLHttpRequest();
    xhr.open("POST", "http://todoteria.com/c/login", true);
    xhr.setRequestHeader('Accept', 'application/json');
    xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
    xhr.setRequestHeader("Content-Length", urlParameters.length);

    xhr.onreadystatechange = function() {
        if (xhr.readyState == xhr.DONE) {
            if (xhr.status == 200) {
                var data = JSON.parse(xhr.responseText);

                var login_token = data['login_token'];
                addUserToDB(email, login_token);

                main.email = email;
                main.login_token = login_token;
                main.state = "";
                setShowEmail();
                mainWindow.synchronize();
            }
            else {
                error.visible = true;
            }
        }
    }

    xhr.send(urlParameters);
}

function net_pingAndPurchase(product_id, sku, name) {
    var xhr = new XMLHttpRequest();
    xhr.open("GET", "http://todoteria.com/c/ping", true);
    xhr.setRequestHeader('Accept', 'application/json');

    xhr.onreadystatechange = function() {
        if (xhr.readyState == xhr.DONE) {
            if (xhr.status == 200) {
                psc.purchase (product_id, sku, name, "");
            }
            else {
                purchaseMessage.text = "todoteria.com site is not accessible or down. Please try later.";
            }
        }
    }

    xhr.send();
}

function net_addpro(product_id, token) {
    if (main.email == '')
        return;

    var urlParameters = "product_id=" + product_id
        + "&token=" + encodeURIComponent(token);

    var xhr = new XMLHttpRequest();
    xhr.open("POST", "http://todoteria.com/c/users/" + encodeURIComponent(main.email) + '/addpro' , true);
    xhr.setRequestHeader('Accept', 'application/json');
    xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
    xhr.setRequestHeader("Content-Length", urlParameters.length);

    xhr.onreadystatechange = function() {
        if (xhr.readyState == xhr.DONE) {
            if (xhr.status == 200) {
                var data = JSON.parse(xhr.responseText);
                main.prottl = data['prottl'];
                var days = Math.ceil(main.prottl / (24*60*60));
                purchaseMessage.text = "You know have pro account for " + days + (days % 10 == 1 ? " day." : " days.")

                saveProTTL(main.prottl);
            }
            else {
                purchaseMessage.text = "Error happened while buying pro account. Please contact us by writing e-mail to help@sandbox.lt";
            }
        }
    }

    xhr.send(urlParameters);
}

/* Helper functions */
function setLinkColor(theme_name) {
    switch (theme_name) {
        case "rose" : main.link_color = "#0000FF"; break;
        case "blue" : main.link_color = "#FF2020"; break;
        case "cyan" : main.link_color = "#FF2020"; break;
        case "electric" : main.link_color = "#FF2020"; break;
        case "green" : main.link_color = "#0000FF"; break;
        case "violet" : main.link_color = "#0000FF"; break;
        case "yellow" : main.link_color = "#0000FF"; break;
        case "bubbles" : main.link_color = "#FF2020"; break;
        case "grid" : main.link_color = "#FF2020"; break;
    }
}
